﻿using System.Collections.Generic;
using System.Web.Mvc;
using SyndicationTest.Models;
using SyndicationTest.Repositories;

namespace SyndicationTest.Controllers
{
    [HandleError]
    public class HomeController : Controller
    {

        private FakeRepository fakeRepository = new FakeRepository();

        /// <summary>
        /// Index Action Result.
        /// </summary>
        /// <returns></returns>
        public ActionResult Index()
        {
            return View();
        }

        /// <summary>
        /// Returns an RSS Feed
        /// </summary>
        /// <param name="id">Accepts an int id.</param>
        /// <returns></returns>
        public RssActionResult GetRssFeed(int id)
        {
            SyndicationFeedItemMapper<MyFeedItem> mapper = SetUpFeedMapper();

            SyndicationFeedOptions options = SetUpFeedOptions();

            IList<MyFeedItem> feedItems = this.fakeRepository.GetLatestFeedItems(id);

            SyndicationFeedHelper<MyFeedItem> feedHelper = SetUpFeedHelper(mapper, options, feedItems);

            return new RssActionResult(feedHelper.GetFeed());
        }

        /// <summary>
        /// Returns an Atom feed.
        /// </summary>
        /// <param name="id">Accepts an int id.</param>
        /// <returns></returns>
        public AtomActionResult GetAtomFeed(int id)
        {
            SyndicationFeedItemMapper<MyFeedItem> mapper = SetUpFeedMapper();

            SyndicationFeedOptions options = SetUpFeedOptions();

            IList<MyFeedItem> feedItems = this.fakeRepository.GetLatestFeedItems(id);

            SyndicationFeedHelper<MyFeedItem> feedHelper = SetUpFeedHelper(mapper, options, feedItems);

            return new AtomActionResult(feedHelper.GetFeed());

        }

        private SyndicationFeedHelper<MyFeedItem> SetUpFeedHelper(SyndicationFeedItemMapper<MyFeedItem> mapper, 
            SyndicationFeedOptions options, IList<MyFeedItem> feedItems)
        {
            SyndicationFeedHelper<MyFeedItem> feedHelper = new SyndicationFeedHelper<MyFeedItem>
                (
                    this.ControllerContext,
                    feedItems,
                    mapper,
                    options
                );
            return feedHelper;
        }

        private static SyndicationFeedOptions SetUpFeedOptions()
        {
            SyndicationFeedOptions options = new SyndicationFeedOptions
                (
                    "My Feed Title",
                    "My Feed Description",
                    "http://mytesturl.com"
                );
            return options;
        }

        private static SyndicationFeedItemMapper<MyFeedItem> SetUpFeedMapper()
        {
            SyndicationFeedItemMapper<MyFeedItem> mapper = new SyndicationFeedItemMapper<MyFeedItem>
                (
                    f => f.Title,
                    f => f.Description,
                    "Home",
                    "Articles",
                    f => f.Id.ToString(),
                    f => f.DateAdded
                );
            return mapper;
        }
    }
}
